local Addon = LibStub("AceAddon-3.0"):GetAddon("Langoustine")
local module = Addon:NewModule("Options")
local L = LibStub("AceLocale-3.0"):GetLocale("LangoustineOptions")

local options = {
	type = "group",
	name = "root",
	args = {
	}
}

function module:OnInitialize()
	self.db = Addon.db.profile
	self:SetupLootOptions()
	self:SetupAutoPromote()
	options.args.Profile = LibStub("AceDBOptions-3.0"):GetOptionsTable(Addon.db)
	LibStub("AceConfig-3.0"):RegisterOptionsTable("Langoustine", options)
	Addon.OptionFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("Langoustine", "Langoustine")
end

function module:SetupAutoPromote()
	local pList = {}
	
	options.args.Promotes = {
		name = L["Auto Promotes"],
		type = "group",
		args = {
			checkbox = {
				name = L["Enabled"],
				desc = L["Enable auto promotions."],
				type = "toggle",
				set = function(info,v) module.db.AutoPromoteEnabled = v end,
				get = function() return module.db.AutoPromoteEnabled end,
				order = 1,
			},
			clearList = {
				name = L["Clear all promotes"],
				type = "execute",
				func = function() wipe(module.db.AutoPromote) end,
				confirm = true,
				confirmText = L["Are you sure you wish to delete all promotions?"],
				order = 50,
			},
			rankGroup = {
				type = "group",
				name = L["Auto Promotions"],
				guiInline = true,
				disabled = function() return not module.db.AutoPromoteEnabled end,
				args = {
					byRank = {
						name = L["Promote by Rank"],
						type = 'select',
						desc = L["Promote any raid member who is this rank for higher."],
						values = function() return Addon.granks end,
						set = function(info,v) module.db.AutoPromoteRank = v end,
						get = function() return module.db.AutoPromoteRank end,
						order = 2,
					},
					byNameInput = {
						name = L["Add Player"],
						type = "input",
						set = function(info, k) module.db.AutoPromote[k] = true end,
						order = 3,
					},
					byName = {
						name = L["Current promotes"],
						type = 'multiselect',
						desc = L["Current list of promotions."],
						values = function() 
							wipe(pList)
							for k,v in pairs(module.db.AutoPromote) do
								pList[k] = k
							end
							return pList
						end,
						set = function(info, k, v) 
							module.db.AutoPromote[k] = v 
							if not v then
								module.db.AutoPromote[k] = nil
							end
						end,
						get = function(info, k) return module.db.AutoPromote[k] end,
					}
				},
			},
		}
	}
end

function module:SetupLootOptions()
	local qList = {}
	qList["2"] = ITEM_QUALITY_COLORS[2].hex..ITEM_QUALITY2_DESC.."|r"
	qList["3"] = ITEM_QUALITY_COLORS[3].hex..ITEM_QUALITY3_DESC.."|r"
	qList["4"] = ITEM_QUALITY_COLORS[4].hex..ITEM_QUALITY4_DESC.."|r"
	qList["5"] = ITEM_QUALITY_COLORS[5].hex..ITEM_QUALITY5_DESC.."|r"
	qList["6"] = ITEM_QUALITY_COLORS[6].hex..ITEM_QUALITY6_DESC.."|r"
	
	options.args.Loot = {
		name = L["Auto Loot"],
		type = "group",
		args = {
			checkbox = {
				name = L["Enabled"],
				desc = L["Enable auto loot configuration."],
				type = "toggle",
				set = function(info,v) module.db.AutoLootEnabled = v end,
				get = function() return module.db.AutoLootEnabled end,
			},
			lootgroup = {
				type = "group",
				guiInline = true,
				name = L["Loot options"],
				disabled = function() return not module.db.AutoLootEnabled end,
				args = {
					method = {
						type = 'select',
						name = LOOT_METHOD,
						values = { ["group"] = LOOT_GROUP_LOOT, ["freeforall"] = LOOT_FREE_FOR_ALL, ["master"] = LOOT_MASTER_LOOTER, ["needbeforegreed"] = LOOT_NEED_BEFORE_GREED, ["roundrobin"] = LOOT_ROUND_ROBIN},
						get = function() return module.db.AutoLoot.method end,
						set = function(info, v) 
							module.db.AutoLoot.method = v 
							module.db.SetLoot = false
							if v == "master" then
								module.db.SetML = false
							end
							Addon:RaidCheck()
						end,
					},
					threshold = {
						type = 'select',
						name = LOOT_THRESHOLD,
						values = qList,
						get = function() return module.db.AutoLoot.threshold end,
						set = function(info, v) 
							module.db.AutoLoot.threshold = v 
							module.db.SetLoot = false
							Addon:RaidCheck()
						end,
					},
					master = {
						type = "input",
						name = LOOT_PROMOTE,
						set = function(info, v) 
							if v ~= module.db.AutoLoot.looter then
								module.db.AutoLoot.looter = v 
								module.db.SetML = false
								Addon:RaidCheck()
							end
						end,
						get = function() return module.db.AutoLoot.looter end,
					}
				}
			}
		}
	}
end